@@ -7,12 +7,10 @@
     Sessions and authentication, templates, etc.
 """
 
+import web
 import os
 from functools import partial
-import web
-from web import wsgiserver
 from reloader import PeriodicReloader
-_https = wsgiserver.CherryPyWSGIServer
 
 def dancefloor(urls, fvars, sessions=False, autoreload=False,
                debug=True, **kwargs):
@@ -34,21 +32,16 @@ def dancefloor(urls, fvars, sessions=False, autoreload=False,
                         an alternate path besides the default, 'sessions/'
         session - a dictionary representing a default init'd session
     """
-    _path = os.path.dirname(os.path.realpath(fvars['__file__']))
+    init_scaffolding(**kwargs)
     app = web.application(_preprocess(urls), fvars, autoreload=autoreload)
     env = {'ctx': web.ctx}
     env.update(kwargs.get('env', {}))
 
-    if type(kwargs.get('ssl', None)) is tuple:        
-        _https.ssl_certificate, _https.ssl_private_key = kwargs.get('ssl')
-
     def setup_rendering():
-        html = partial(web.template.render, '%s/templates/' % _path)
+        html = partial(web.template.render, '%s/templates/' % os.getcwd())
         slender = html(globals=env)
         render = html(base='base', globals=env)
-        def render_hook():
-            web.ctx.render = render
-            web.ctx.slender = slender
+        def render_hook(): web.ctx.render = render
         app.add_processor(web.loadhook(render_hook))
         env['render'] = slender
 
@@ -59,7 +52,7 @@ def dancefloor(urls, fvars, sessions=False, autoreload=False,
         def default_store():
             """Default method of storing session: DiskStore
             created directory sessions/ by default to store sessions"""
-            path = _path + '/sessions'
+            path = os.getcwd() + '/sessions'
             if not os.path.exists(path):
                 os.makedirs(path)
             return web.session.DiskStore(path)
@@ -69,21 +62,12 @@ def dancefloor(urls, fvars, sessions=False, autoreload=False,
         env['session'] = session
 
     def setup_waltz():
-        def fcgi(func, addr=None):
-            """nginx with spawn-fcgi"""
-            return web.wsgi.runfcgi(func, addr)
-        web.config.debug = debug
+        web.config.debug = debug        
         if debug:
             PeriodicReloader()
-        if kwargs.get('fcgi'):
-            web.wsgi.runwsgi = fcgi
-        db = kwargs.get('db', "%s/db" % _path)
-        lgr = kwargs.get('logging', '%s/events.log' % _path)
+        db = kwargs.get('db', "%s/db" % os.getcwd())
         def waltz_hook():
-            web.ctx.waltz = {"debug": debug,
-                             "db": db,
-                             "logging": lgr
-                             }
+            web.ctx.waltz = {"debug": debug, "db": db}
         app.add_processor(web.loadhook(waltz_hook))        
 
     setup_rendering()
@@ -104,30 +88,25 @@ def init_sessions(web, app, store, session):
     app.add_processor(web.loadhook(inject_session))
     return session
 
-def init_scaffolding(_path, appname="main.py", **kwargs):
+def init_scaffolding(**kwargs):
     """Builds scaffolding for the project:
     static/, templates/, routes/, subapps/"""
 
     def build_static():
         """Builds a static/ directory within the project
         with subdirs: static/css, static/js, and static/imgs"""
-        from waltz.static import style
-        path = _path + '/static'
+        path = os.getcwd() + '/static'
         if not os.path.exists(path):
             os.makedirs(path)
         for subdir in ['css', 'js', 'imgs']:
             subpath = '%s/%s' % (path, subdir)
             if not os.path.exists(subpath):
                 os.makedirs(subpath)
-        stylecss = path + "/css/style.css"
-        if not os.path.exists(stylecss):
-            with open(stylecss, 'w') as f:
-                f.write(style)
 
     def build_routes():
         """Creates directories + __init__ files for route logic"""
         for d in ['routes', 'subapps']:
-            path = '%s/%s' % (_path, d)
+            path = '%s/%s' % (os.getcwd(), d)
             if not os.path.exists(path):
                 os.makedirs(path)
                 fname = '%s/%s' % (path, '__init__.py')
@@ -136,7 +115,7 @@ def init_scaffolding(_path, appname="main.py", **kwargs):
     def build_templates():
         """Builds the templates/ directory"""
         from waltz.static import base, index
-        path = '%s/templates' % _path
+        path = '%s/templates' % os.getcwd()
         if not os.path.exists(path):
             os.makedirs(path)
         for fname, content in [('base', base), ('index', index)]:
@@ -144,24 +123,11 @@ def init_scaffolding(_path, appname="main.py", **kwargs):
             if not os.path.exists(base): 
                 with open(base, 'w') as f:
                     f.write(content)
-    
-    def build_app(appname):
-        from waltz.static import mainpy, homepy
-        appname += ".py" if appname[-3:] != ".py" else ""
-        homepypath = '%s/routes/home.py' % _path
-        mainpypath = '%s/%s' % (_path, appname)
-        for fname, content in [(mainpypath, mainpy),
-                               (homepypath, homepy)]:
-            if not os.path.exists(fname): 
-                with open(fname, 'w') as f:
-                    f.write(content)            
 
     build_static()
     build_routes()
     build_templates()
-    build_app(appname)
 
 def _preprocess(urls):
     """Can be used to inject routes in the future"""
     return urls
-
